@@ -18,15 +18,31 @@ try:
 except ModuleNotFoundError:
     pass
 
-__version__ = '0.1.3'
-__release__ = 20230204
+__version__ = '0.1.4'
+__release__ = 20230205
 
 
-def dlis2frame(path: str, use_simpandas=False, raise_error=False):
+class DLISIOError(Exception):
+    """
+    Error raised while reading LAS file.
+    """
+    def __init__(self, message='raised by dlisio.'):
+        self.message = 'ERROR: reading DLIS file ' + message
+
+
+def dlis2frame(path: str, use_simpandas=False, raise_error=True):
     if not os.path.isfile(path):
         raise FileNotFoundError("The provided path can't be found:\n" + str(path))
 
-    physical_file = dlis.load(path)
+    try:
+        physical_file = dlis.load(path)
+    except:  # any possible error raised at this point will be raised by dlisio
+        if raise_error:
+            raise DLISIOError("Error raised by dlisio while reading: " + str(path))
+        else:
+            logging.warning("Error raised by dlisio while reading: " + str(path))
+            return None
+
     frames = {}
     l_count = -1
     for logical_file in physical_file:
